==> ppi_client-1.1.2.tar.gz: ppi_client-1.1.2/ppi_client/api/constants.py <==
ACCOUNT_LOGIN = '1.0/Account/Login'
ACCOUNT_REFRESH_TOKEN = '1.0/Account/RefreshToken'
ACCOUNT_ACCOUNTS = '1.0/Account/Accounts'
ACCOUNT_BANK_ACCOUNTS = '1.0/Account/BankAccounts?accountNumber={0}'
ACCOUNT_AVAILABLE_BALANCE = '1.0/Account/AvailableBalance?accountNumber={0}'
ACCOUNT_BALANCE_POSITIONS = '1.0/Account/BalancesAndPositions?accountNumber={0}'
ACCOUNT_MOVEMENTS = '1.0/Account/Movements?accountNumber={0}'
ACCOUNT_INVESTING_PROFILE_QUESTIONS = '1.0/Account/InvestingProfileQuestions'
ACCOUNT_INVESTING_PROFILE_INSTRUMENT_TYPES = '1.0/Account/InvestingProfileInstrumentTypes'
ACCOUNT_INVESTING_PROFILE = '1.0/Account/InvestingProfile?accountNumber={0}'
ACCOUNT_SET_INVESTING_PROFILE = '1.0/Account/InvestingProfile'
ACCOUNT_REGISTER_BANK_ACCOUNT = '1.0/Account/BankAccount'
ACCOUNT_REGISTER_FOREIGN_BANK_ACCOUNT = '1.0/Account/ForeignBankAccount'
ACCOUNT_CANCEL_BANK_ACCOUNT = '1.0/Account/CancelBankAccount'

CONFIGURATION_INSTRUMENT_TYPES = '1.0/Configuration/InstrumentTypes'
CONFIGURATION_MARKETS = '1.0/Configuration/Markets'
CONFIGURATION_SETTLEMENTS = '1.0/Configuration/Settlements'
CONFIGURATION_QUANTITY_TYPES = '1.0/Configuration/QuantityTypes'
CONFIGURATION_OPERATION_TERMS = '1.0/Configuration/OperationTerms'
CONFIGURATION_OPERATION_TYPES = '1.0/Configuration/OperationTypes'
CONFIGURATION_OPERATIONS = '1.0/Configuration/Operations'
CONFIGURATION_HOLIDAYS = '1.0/Configuration/Holidays'
CONFIGURATION_IS_LOCAL_HOLIDAY = '1.0/Configuration/IsLocalHoliday'
CONFIGURATION_IS_USA_HOLIDAY = '1.0/Configuration/IsUSAHoliday'

MARKETDATA_SEARCH_INSTRUMENT = '1.0/MarketData/SearchInstrument?ticker={0}&name={1}&market={2}&type={3}'
MARKETDATA_SEARCH = '1.0/MarketData/Search?ticker={0}&type={1}&dateFrom={2}&dateTo={3}&settlement={4}'
MARKETDATA_CURRENT = '1.0/MarketData/Current?ticker={0}&type={1}&settlement={2}'
MARKETDATA_BOOK = '1.0/MarketData/Book?ticker={0}&type={1}&settlement={2}'
MARKETDATA_INTRADAY = '1.0/MarketData/Intraday?ticker={0}&type={1}&settlement={2}'

ORDER_ORDERS = '1.0/Order/Orders?accountNumber={0}&dateFrom={1}&dateTo={2}'
ORDER_ACTIVE_ORDERS = '1.0/Order/ActiveOrders?accountNumber={0}'
ORDER_DETAIL = '1.0/Order/Detail?accountNumber={0}&orderID={1}&externalID={2}'
ORDER_BUDGET = '1.0/Order/Budget'
ORDER_CONFIRM = '1.0/Order/Confirm'
ORDER_CANCEL = '1.0/Order/Cancel'
ORDER_MASS_CANCEL = '1.0/Order/MassCancel?accountNumber={0}'

HTTP_STATUS = 'httpStatus'
HTTP_RESPONSE = 'httpResponse'
MIME_JSON = "application/json"
MIME_FORM = "application/x-www-form-urlencoded"

MARKETDATA_HUB = 'MarketData'
ACCOUNTDATA_HUB = 'Account'
ACCOUNTDATA_TYPE_ACCOUNT_NOTIFICATION = 'AccountNotification'
ACCOUNTDATA_TYPE_PUSH_NOTIFICATION = 'PushNotification'
ACCOUNTDATA_TYPE_ORDER_NOTIFICATION = 'OrderNotification'

==> ppi_client-1.2.0.tar.gz: ppi_client-1.2.0/ppi_client/api/constants.py <==
ACCOUNT_LOGIN_API = '1.0/Account/LoginApi'
ACCOUNT_REFRESH_TOKEN = '1.0/Account/RefreshToken'
ACCOUNT_ACCOUNTS = '1.0/Account/Accounts'
ACCOUNT_BANK_ACCOUNTS = '1.0/Account/BankAccounts?accountNumber={0}'
ACCOUNT_AVAILABLE_BALANCE = '1.0/Account/AvailableBalance?accountNumber={0}'
ACCOUNT_BALANCE_POSITIONS = '1.0/Account/BalancesAndPositions?accountNumber={0}'
ACCOUNT_MOVEMENTS = '1.0/Account/Movements?accountNumber={0}'
ACCOUNT_INVESTING_PROFILE_QUESTIONS = '1.0/Account/InvestingProfileQuestions'
ACCOUNT_INVESTING_PROFILE_INSTRUMENT_TYPES = '1.0/Account/InvestingProfileInstrumentTypes'
ACCOUNT_INVESTING_PROFILE = '1.0/Account/InvestingProfile?accountNumber={0}'
ACCOUNT_SET_INVESTING_PROFILE = '1.0/Account/InvestingProfile'
ACCOUNT_REGISTER_BANK_ACCOUNT = '1.0/Account/BankAccount'
ACCOUNT_REGISTER_FOREIGN_BANK_ACCOUNT = '1.0/Account/ForeignBankAccount'
ACCOUNT_CANCEL_BANK_ACCOUNT = '1.0/Account/CancelBankAccount'

CONFIGURATION_INSTRUMENT_TYPES = '1.0/Configuration/InstrumentTypes'
CONFIGURATION_MARKETS = '1.0/Configuration/Markets'
CONFIGURATION_SETTLEMENTS = '1.0/Configuration/Settlements'
CONFIGURATION_QUANTITY_TYPES = '1.0/Configuration/QuantityTypes'
CONFIGURATION_OPERATION_TERMS = '1.0/Configuration/OperationTerms'
CONFIGURATION_OPERATION_TYPES = '1.0/Configuration/OperationTypes'
CONFIGURATION_OPERATIONS = '1.0/Configuration/Operations'
CONFIGURATION_HOLIDAYS = '1.0/Configuration/Holidays'
CONFIGURATION_IS_LOCAL_HOLIDAY = '1.0/Configuration/IsLocalHoliday'
CONFIGURATION_IS_USA_HOLIDAY = '1.0/Configuration/IsUSAHoliday'

MARKETDATA_SEARCH_INSTRUMENT = '1.0/MarketData/SearchInstrument?ticker={0}&name={1}&market={2}&type={3}'
MARKETDATA_SEARCH = '1.0/MarketData/Search?ticker={0}&type={1}&dateFrom={2}&dateTo={3}&settlement={4}'
MARKETDATA_CURRENT = '1.0/MarketData/Current?ticker={0}&type={1}&settlement={2}'
MARKETDATA_BOOK = '1.0/MarketData/Book?ticker={0}&type={1}&settlement={2}'
MARKETDATA_INTRADAY = '1.0/MarketData/Intraday?ticker={0}&type={1}&settlement={2}'
ESTIMATE_BONDS = '1.0/MarketData/Bonds/Estimate'

ORDER_ORDERS = '1.0/Order/Orders?accountNumber={0}&dateFrom={1}&dateTo={2}'
ORDER_ACTIVE_ORDERS = '1.0/Order/ActiveOrders?accountNumber={0}'
ORDER_DETAIL = '1.0/Order/Detail?accountNumber={0}&orderID={1}&externalID={2}'
ORDER_BUDGET = '1.0/Order/Budget'
ORDER_CONFIRM = '1.0/Order/Confirm'
ORDER_CANCEL = '1.0/Order/Cancel'
ORDER_MASS_CANCEL = '1.0/Order/MassCancel?accountNumber={0}'
TRANSFER_BUDGET = '1.0/Order/BudgetTransfer'
TRANSFER_CONFIRM = '1.0/Order/ConfirmTransfer'

HTTP_STATUS = 'httpStatus'
HTTP_RESPONSE = 'httpResponse'
MIME_JSON = "application/json"
MIME_FORM = "application/x-www-form-urlencoded"

MARKETDATA_HUB = 'MarketData'
ACCOUNTDATA_HUB = 'Account'
ACCOUNTDATA_TYPE_ACCOUNT_NOTIFICATION = 'AccountNotification'
ACCOUNTDATA_TYPE_PUSH_NOTIFICATION = 'PushNotification'
ACCOUNTDATA_TYPE_ORDER_NOTIFICATION = 'OrderNotification'
